@@ -31,7 +31,7 @@ double powerDL(double x, double lambda, int yj);
 SEXP _rxProgress(SEXP num, SEXP core);
 SEXP _rxTick();
 SEXP _rxProgressStop(SEXP);
-SEXP _rxProgressAbort();
+SEXP _rxProgressAbort(SEXP);
 SEXP _RxODE_codeLoaded();
 
 SEXP _RxODE_trans(SEXP parse_file, SEXP extra_c, SEXP prefix, SEXP model_md5, SEXP isStr, SEXP);
@@ -154,7 +154,7 @@ void R_init_RxODE(DllInfo *info){
     {"_rxProgress", (DL_FUNC) &_rxProgress, 2},
     {"_rxTick", (DL_FUNC) &_rxTick, 0},
     {"_rxProgressStop", (DL_FUNC) &_rxProgressStop, 1},
-    {"_rxProgressAbort", (DL_FUNC) &_rxProgressAbort, 0},
+    {"_rxProgressAbort", (DL_FUNC) &_rxProgressAbort, 1},
     {"_RxODE_trans", (DL_FUNC) &_RxODE_trans, 6},
     {"_RxODE_codegen", (DL_FUNC) &_RxODE_codegen, 6},
     {"_RxODE_codeLoaded", (DL_FUNC) &_RxODE_codeLoaded, 0},
